@@ -1,5 +1,5 @@
 <?php
-if (containsModule(get_requested_pagename(), "countdown")) {
+if (containsModule(get_slug(), "countdown")) {
     ?>
 <script type="text/javascript"
 	src="<?php
